# Recurring components

These are the components that have the possibility to be recurring. For each of them there is their standard class and their recurring class. The idea is that the original definition is represented by the standard class and any occurrence that is generated based on the recurring properties, is represented by the recurring class.

Given all classes that have recurring options have a major overlap, there are two class abstracting the complexity away from them. This is again in the same concept, where the first one covers the standard class, and the other one covers the recurring class. These two are listed here first before the rest.

::: ical_library.ical_components.abstract_components.AbstractComponentWithRecurringProperties

::: ical_library.ical_components.abstract_components.AbstractRecurrence


::: ical_library.ical_components.VEvent

::: ical_library.ical_components.VRecurringEvent

::: ical_library.ical_components.VToDo

::: ical_library.ical_components.VRecurringToDo

::: ical_library.ical_components.VJournal

::: ical_library.ical_components.VRecurringJournal
